<?php
/**
 * Plugin Name: F1 Register Flow
 * Description: Customizations to the registration process enabling a custom register form as well as requiring the user to confirm registration via email.
 * Version: 1.0
 * Author: F1 Code
 * License: GPLv2 or later
 *
 * Copyright (C) 2015 F1 Code
 */

spl_autoload_register(function ($class) {
    // project-specific namespace prefix
    $prefix = 'F1\\RegisterFlow\\';

    // base directory for the namespace prefix
    $base_dir = __DIR__ . '/src/';

    // does the class use the namespace prefix?
    $len = strlen($prefix);
    if (strncmp($prefix, $class, $len) !== 0) {
        // no, move to the next registered autoloader
        return;
    }

    // get the relative class name
    $relative_class = substr($class, $len);

    // replace the namespace prefix with the base directory, replace namespace
    // separators with directory separators in the relative class name, append
    // with .php
    $file = $base_dir . str_replace('\\', '/', $relative_class) . '.php';

    // if the file exists, require it
    if (file_exists($file)) {
        require $file;
    }
});

add_action('wp_loaded', [new \F1\RegisterFlow\Confirmation(), 'registerHooks']);
add_action('wp_loaded', [new \F1\RegisterFlow\Shortcodes(), 'registerShortcodes']);
add_action('wp_loaded', [new \F1\RegisterFlow\PostHandler(), 'handlePostData'], 30);
add_filter('register_url', function () {
    return \F1\RegisterFlow\OptionPage::getPageLink(\F1\RegisterFlow\OptionPage::OPTION_PAGE_STEP1);
});
add_action('plugins_loaded', [new \F1\RegisterFlow\OptionPage(), 'registerOptionPage']);
