<?php
/**
 * Confirmation.php
 * Created By: nico
 * Created On: 8/15/2015
 */

namespace F1\RegisterFlow;

/**
 * Confirmation step, called from the login page
 *
 * @package F1\RegisterFlow
 */
class Confirmation extends RegistrationBase
{
    private $registrationError;

    public function registerHooks()
    {
        add_action('login_form_confirmregistration', array(&$this, 'onLoginConfirmRegistration'));
        add_filter('wp_login_errors', array(&$this, 'showLoginErrors'));
    }

    public function onLoginConfirmRegistration()
    {
        $error = $this->_processConfirmRegistration($_GET['registration_key']);
        if (is_wp_error($error)) {
            $this->registrationError = implode('<br/>', $error->get_error_messages());
        }
    }

    private function _processConfirmRegistration($registrationKey)
    {
        $post = get_page_by_title($registrationKey, OBJECT, 'f1_registration');
        if (!$post) {
            return new \WP_Error('invalid_key', __('Invalid registration key', 'f1-register-flow'));
        }
        $userData = json_decode($post->post_content, true);
        $err = $this->validateRequiredData($userData);
        if (!empty($err->errors))
            return $err;
        $err = new \WP_Error();

        $userData = apply_filters('f1_registration_confirmation_validate', $userData, $err);
        if (!empty($err->errors))
            return $err;
        $login = $userData['registration_login'];
        $userId = wp_insert_user(array(
                'user_login' => $login,
                'user_pass' => $userData['registration_password'],
                'user_email' => $userData['registration_email'],
                'first_name' => $userData['registration_first'],
                'last_name' => $userData['registration_last'],
                'user_registered' => date('Y-m-d H:i:s'),
                'role' => 'subscriber'
            )
        );

        if (!is_wp_error($userId)) {
            wp_delete_post($post->ID, true);

            do_action('f1_registration_confirmed', $userId, $userData);

            // send an email to the admin alerting them of the registration
            wp_new_user_notification($userId);

            // send authentication cookie to mark user as logged in
            wp_set_auth_cookie($userId, true);
            wp_set_current_user($userId, $login);
            do_action('wp_login', $login);

            if (has_action('f1_registration_loggedin')) {
                do_action('f1_registration_loggedin', $userId);
            } else {
                // redirect to home page
                wp_redirect(home_url());
                exit;
            }
        }
        return $userId;
    }

    /**
     * Filter for login errors.  If we have any accumulated error, now is the time to show them.
     *
     * @param \WP_Error $errors
     * @return \WP_Error
     */
    public function showLoginErrors($errors)
    {
        if (!empty($this->registrationError)) {
            $errors->add('f1_registration_error', $this->registrationError);
        }
        return $errors;
    }
}
