<?php
/**
 * EmailService.php
 * Created By: nico
 * Created On: 8/17/2015
 */

namespace F1\RegisterFlow;


class EmailService implements EmailServiceInterface
{
    /**
     * Send confirmation request to the address specified in $registrationData[registration_email]
     *
     * @param array $registrationData
     * @param string $registrationKey
     */
    public function sendConfirmationRequest($registrationData, $registrationKey)
    {
        $email = $registrationData['registration_email'];
        $email = apply_filters('f1_registration_confirmation_request_email', $email, $registrationData);
        $registrationData['registration_confirmation_url'] = wp_login_url(home_url()) .
            '&action=confirmregistration' .
            '&registration_key=' . urlencode($registrationKey);
        $this->_sendTemplatedEmail(OptionPage::OPTION_PAGE_CONFIRM_EMAIL_TEMPLATE, $email, $registrationData);
    }

    private function _sendTemplatedEmail($templateOptionId, $email, $data)
    {
        $pageId = OptionPage::getOption($templateOptionId);
        if ($pageId && ($post = get_post($pageId))) {
            $content = $post->post_content;
            $content = $this->_expandTemplateVariables($content, $data);
            $title = $post->post_title;
            $title = $this->_expandTemplateVariables($title, $data);
            wp_mail($email, $title, $content);
        } else {
            die("No template $templateOptionId");
        }
    }

    private function _expandTemplateVariables($content, $data)
    {
        foreach($data as $k => $v) {
            $content = str_replace('{{'.$k.'}}', $v, $content);
        }
        return $content;
    }
}