<?php
/**
 * FormHandler.php
 * Created By: nico
 * Created On: 8/15/2015
 */

namespace F1\RegisterFlow;

/**
 * Intercept POST request to determine if they are part of the registration flow.
 * If they are, then route them to the appropriate class
 *
 * @package F1\RegisterFlow
 */
class PostHandler
{
    public function handlePostData()
    {
        // TODO this should be more flexible, what if I want a different number of steps?
        // All the "intermediate" steps could be the same, with the "final" step being a bit special since it
        // needs to send a confirmation email
        // We'd need to make sure the form data is retained from 1 step to the next
        $this->_processStep1Fields();
        $this->_processStep2Fields();
    }


    /**
     * Process post data for registration field, if present.
     */
    private function _processStep1Fields()
    {
        if (isset($_POST['_registration_step1_nonce']) && wp_verify_nonce($_POST['_registration_step1_nonce'], 'f1-registration')) {
            // Means they are posting the form so we can process it
            // Redirect to confirmation if verification is successful
            $reg = new RegistrationStep1();
            $formData = $this->extractRegistrationFields($_REQUEST);
            $result = $reg->processFormData($formData);
            if (!is_wp_error($result)) {
                $result['_registration_step2_nonce'] = wp_create_nonce('f1-registration');
                $q = http_build_query($result);
                $redirect = OptionPage::getPageLink(OptionPage::OPTION_PAGE_STEP2, $q);
                wp_redirect($redirect);
                exit;
            }
            Shortcodes::$errors = $result;
        }
    }

    /**
     * Process post data for registration step2, if present.
     */
    private function _processStep2Fields()
    {
        if (isset($_POST['_registration_step2_nonce']) && wp_verify_nonce($_POST['_registration_step2_nonce'], 'f1-registration')) {
            // Means they are posting the form so we can process it
            // Redirect to confirmation if verification is successful
            $reg = new RegistrationStep2(new EmailService());
            $formData = $this->extractRegistrationFields($_REQUEST);
            $result = $reg->processFormData($formData);
            if (!is_wp_error($result)) {
                wp_redirect(OptionPage::getPageLink(OptionPage::OPTION_PAGE_CONFIRM));
                exit;
            }
            Shortcodes::$errors = $result;
        }
    }

    private function extractRegistrationFields($postData)
    {
        $result = [];
        foreach($postData as $k => $v) {
            if(strpos($k, 'registration_') === 0)
                $result[$k] = $v;
        }
        return $result;
    }
}