<?php
/**
 * RegistrationBase.php
 * Created By: nico
 * Created On: 8/15/2015
 */

namespace F1\RegisterFlow;


class RegistrationBase
{
    /**
     * Validate the data that is present.
     *
     * @param array $userData
     * @param \WP_Error $errors
     * @return \WP_Error
     */
    protected function validateAvailableData($userData, $errors = null)
    {
        if (!$errors)
            $errors = new \WP_Error();
        $login = isset($userData['registration_login']) ? $userData['registration_login'] : null;
        $email = isset($userData['registration_email']) ? $userData['registration_email'] : null;
        $pass = isset($userData['registration_password']) ? $userData['registration_password'] : null;
        if ($login && username_exists($login)) {
            // Username already registered
            /** @noinspection HtmlUnknownTarget */
            $msg = __('Username already taken.  <a href=\'%s\'>Lost password?</a>', 'f1-register-flow');
            $errors->add('username_unavailable', sprintf($msg, wp_lostpassword_url()));
        } else if ($login && !validate_username($login)) {
            // invalid username
            $errors->add('username_invalid', __('Invalid username', 'f1-register-flow'));
        } else if ($email && !is_email($email)) {
            //invalid email
            $errors->add('email_invalid', __('Invalid email', 'f1-register-flow'));
        } else if ($email && email_exists($email)) {
            //Email address already registered
            /** @noinspection HtmlUnknownTarget */
            $msg = __('Email already registered.  <a href=\'%s\'>Lost password or username?</a>', 'f1-register-flow');
            $errors->add('email_used', sprintf($msg, wp_lostpassword_url()));
        } else if ($pass !== null && $pass != $userData['registration_password_confirm']) {
            // passwords do not match
            $errors->add('password_mismatch', __('Passwords do not match', 'f1-register-flow'));
        }
        return $errors;
    }

    /**
     * Called in final registration step, ensures all required data is present.
     *
     * @param array $formData
     * @param \WP_Error $errors
     * @return \WP_Error
     */
    protected
    function validateRequiredData($formData, $errors = null)
    {
        if (!$errors)
            $errors = new \WP_Error();
        if (empty($formData['registration_email'])) {
            $errors->add('invalid_email', __('Please provide email', 'f1-register-flow'));
        }
        if (empty($formData['registration_login'])) {
            $errors->add('invalid_login', __('Please provide user name', 'f1-register-flow'));
        }
        if (empty($formData['registration_last']) || empty($formData['registration_first'])) {
            $errors->add('invalid_name', __('Please provide first and last name', 'f1-register-flow'));
        }
        if (empty($formData['registration_password'])) {
            $errors->add('invalid_password', __('Please provide password', 'f1-register-flow'));
        }
        return $errors;
    }

}
