<?php
/**
 * RegistrationStep2.php
 * Created By: nico
 * Created On: 8/15/2015
 */

namespace F1\RegisterFlow;


class RegistrationStep2 extends RegistrationBase
{
    private $emailService;

    /**
     * @param EmailServiceInterface $emailService
     */
    function __construct(EmailServiceInterface $emailService)
    {
        $this->emailService = $emailService;
    }

    /**
     * Create temporary user data and send confirmation request.
     *
     * @param $formData
     * @return \WP_Error Error, if any, or registration key if no error
     */
    public function processFormData(&$formData)
    {
        $errors = new \WP_Error();

        $formData = apply_filters('f1_registration_step2_validate', $formData, $errors);
        $this->validateAvailableData($formData, $errors);
        $this->validateRequiredData($formData, $errors);
        if (!empty($errors->errors))
            return $errors;
        $regKey = $this->_insertTemporaryUserData($formData);
        if (is_wp_error($regKey)) {
            return $regKey;
        }
        $this->emailService->sendConfirmationRequest($formData, $regKey);
        return $regKey;
    }

    private function _insertTemporaryUserData($formData)
    {
        $regKey = $this->_generateRegistrationKey();
        $confirmationId = wp_insert_post([
            'post_type' => 'f1_registration',
            'post_title' => $regKey,
            'post_content' => json_encode($formData)
        ], true);
        if (!is_wp_error($confirmationId)) {
            return $regKey;
        }
        return $confirmationId;
    }

    private function _generateRegistrationKey()
    {
        $key = wp_generate_password(20, false);
        return $key;
    }
}