<?php
/**
 * Shortcodes.php
 * Created By: nico
 * Created On: 8/15/2015
 */

namespace F1\RegisterFlow;


class Shortcodes
{
    /** @var \WP_Error */
    public static $errors = null;

    public function registerShortcodes()
    {
        add_shortcode('f1-registration-form-step1', array(&$this, 'registrationFormStep1'));
        add_shortcode('f1-registration-form-step2', array(&$this, 'registrationFormStep2'));
    }

    /**
     * Output code for the registration form.  Include error message if any.
     */
    public function registrationFormStep1($atts, $content = '')
    {
        $content = do_shortcode($content);
        $output = '<form id="registration_form" method="POST" action="" novalidate>' . $content;
        $output .= wp_nonce_field('f1-registration', '_registration_step1_nonce', true, false);
        $output .= self::_getErrorMessages();
        $output .= '</form>';
        return $output;
    }

    public function registrationFormStep2($atts, $content = '')
    {
        $content = do_shortcode($content);
        if (!(isset($_REQUEST['_registration_step2_nonce']) &&
            wp_verify_nonce($_REQUEST['_registration_step2_nonce'], 'f1-registration'))
        ) {
            // they are coming without the required query string parameters
            // output javascript to redirect them to the register page (we can't use wp_redirect here)
            return "<script type='text/javascript'>window.location.href = '" . home_url('/register') . "';</script>";
        }
        $output = '<form id="registration_form" method="POST" action="" novalidate>' . $content;
        $output .= wp_nonce_field('f1-registration', '_registration_step2_nonce', true, false);
        $output .= self::_getErrorMessages();
        $output .= $this->_generatePopulateFieldsScript($_REQUEST);
        // any registration request input that is not a field in the content should now be included as a hidden field
//        $output .= $this->_generateHiddenFields($_REQUEST, $content);
        $output .= '</form>';
        return $output;
    }

    private static function _getErrorMessages()
    {
        if (is_wp_error(self::$errors)) {
            return '<div class="error">' . implode('<br/>', self::$errors->get_error_messages()) . '</div>';
        }
        return '';
    }
//
//    private function _generateHiddenFields($requestData, $html)
//    {
//        $output = '';
//        foreach ($requestData as $k => $v) {
//            if (strpos($k, 'registration_') === 0 && strpos($html, $k) === false) {
//                $output .= '<input type="hidden" name="' . esc_attr($k) . '" value="' . esc_attr($v) . '"/>';
//            }
//        }
//        return $output;
//    }

    /**
     * Generate javascript that will populate the controls present on the form.
     *
     * @param $requestData
     * @return string
     */
    private function _generatePopulateFieldsScript($requestData)
    {
        $script = '';
        foreach ($requestData as $k => $v) {
            if ($v && strpos($k, 'registration_') === 0) {
//                $output = preg_replace('/<input[^>]*name=["\']'.$k.'["\']/i', '$0 value="'.esc_attr($v).'"', $output, 1);
                $script .= "$('[name=$k]')";
                if ($v === 'on' || $v == '1') {
                    $script .= '.prop("checked", true)';
                } else {
                    $script .= '.val("' . esc_js($v) . '");';
                }
            }
        }

        if ($script) {
            /** @noinspection JSUnusedLocalSymbols */
            return '<script type="text/javascript">jQuery(document).ready(function($) { ' . $script . ' });</script>';
        }
        return '';
    }

}